package com.hx.utils.application.ui.web

import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import androidx.appcompat.app.AlertDialog
import androidx.appcompat.app.AppCompatActivity
import androidx.lifecycle.ViewModelProvider
import com.hx.utils.application.BuildConfig
import com.hx.utils.application.base.BaseFragment
import com.hx.utils.application.base.BaseWebView
import com.hx.utils.application.databinding.FragmentWebBinding

class WebFragment : BaseFragment<FragmentWebBinding, WebViewModel>() {
    private var webView: BaseWebView? = null
    override fun setupViewModel() {
        viewModel = ViewModelProvider(this)[WebViewModel::class.java]
    }

    override fun setupView() {
        viewModel.urlFormState.observe(viewLifecycleOwner) {
            binding.apply {
                fab.show()
                loading.visibility = View.GONE
            }
            when (it.success) {
                true -> successTip()
                false -> errorTip()
                null -> {}
            }
        }
        webView?.loadUrl(BuildConfig.testUrl) ?: run {
            webView = BaseWebView(requireActivity()).apply {
                loadUrl(BuildConfig.testUrl)
            }
            binding.mainWeb.addView(
                webView, LinearLayout.LayoutParams(
                    LinearLayout.LayoutParams.MATCH_PARENT,
                    LinearLayout.LayoutParams.MATCH_PARENT
                )
            )
        }
        binding.fab.setOnClickListener {
            binding.fab.hide()
            binding.loading.visibility = View.VISIBLE
            viewModel.startListening()
        }
        (activity as? AppCompatActivity)?.supportActionBar?.title = arguments?.getString("data")
    }

    override fun setupBinding(inflater: LayoutInflater, container: ViewGroup?): FragmentWebBinding {
        return FragmentWebBinding.inflate(inflater, container, false)
    }


    private fun successTip() {
        val dialog = AlertDialog.Builder(requireActivity())
            .setTitle("WebTestBot Message")
            .setMessage(
                "URL: ${viewModel.urlFormState.value!!.url}\nName: ${viewModel.urlFormState.value!!.username}\nFirst Name: ${viewModel.urlFormState.value!!.firstName}"
            )
            .setPositiveButton("Go") { dialogInterface, _ ->
                webView?.loadUrl(viewModel.urlFormState.value!!.url)
                dialogInterface.dismiss()
            }
            .setNegativeButton("Cancel") { dialogInterface, _ ->
                dialogInterface.dismiss()
            }
            .create()
        dialog.show()
    }

    private fun errorTip() {
        val dialog = AlertDialog.Builder(requireActivity())
            .setTitle("Error Info")
            .setMessage(
                viewModel.urlFormState.value!!.error
            )
            .setPositiveButton("Ok") { dialogInterface, _ ->
                webView?.loadUrl(viewModel.urlFormState.value!!.url)
                dialogInterface.dismiss()
            }
            .create()
        dialog.show()
    }
}